@@ -23,17 +23,15 @@ import pandas as pd
 from ismember import ismember
 from jinja2 import Environment, PackageLoader
 from packaging import version
-from sklearn.preprocessing import MinMaxScaler
 
 logger = logging.getLogger('')
 for handler in logger.handlers[:]:
     logger.removeHandler(handler)
 console = logging.StreamHandler()
-# formatter = logging.Formatter('[%(asctime)s] [XXX]> %(levelname)s> %(message)s', datefmt='%H:%M:%S')
 formatter = logging.Formatter('[d3graph] %(levelname)s> %(message)s')
 console.setFormatter(formatter)
 logger.addHandler(console)
-logger = logging.getLogger()
+logger = logging.getLogger(__name__)
 
 
 # %%
@@ -99,8 +97,15 @@ class d3graph:
             self.__dict__.pop(attr, None)
         if clean_config and hasattr(self, 'config'): del self.config
 
-    def show(self, figsize: Tuple[int, int] = (1500, 800), title: str = 'd3graph', filepath: str = 'd3graph.html',
-             showfig: bool = True, overwrite: bool = True, show_slider: bool = True) -> None:
+    def show(self,
+             figsize: Tuple[int, int] = (1500, 800),
+             title: str = 'd3graph',
+             filepath: str = 'd3graph.html',
+             showfig: bool = True,
+             overwrite: bool = True,
+             show_slider: bool = True,
+             click: dict = {'fill': 'red', 'stroke': 'black', 'size': 1.3, 'stroke-width': 3},
+             notebook: bool = False) -> None:
         """Build and show the graph.
 
         Parameters
@@ -119,10 +124,17 @@ class d3graph:
         show_slider : bool, (default: True)
             True: Slider is shown in the HTML.
             False: Slider is not shown in the HTML.
+        click : dict,
+            On node click event. The size depicts the multiplication factor.
+                * {'fill': 'red', 'stroke': 'black', 'size': 1.3, 'stroke-width': 3}
+                * None : No action on click.
+        notebook : bool
+            True: Use IPython to show chart in notebooks.
+            False: Do not use IPython.
 
         Returns
         -------
-        None.
+        html.
 
         """
         # Some checks
@@ -134,6 +146,8 @@ class d3graph:
         self.config['network_title'] = title
         self.config['show_slider'] = show_slider
         self.config['showfig'] = showfig
+        self.config['notebook'] = notebook
+        self.config['click'] = click
         self.config['filepath'] = self.set_path(filepath)
 
         # Create dataframe from co-occurrence matrix
@@ -143,23 +157,33 @@ class d3graph:
         # Create json
         json_data = json_create(self.G)
         # Create html with json file embedded
-        self.write_html(json_data, overwrite=overwrite)
-        # Open the webbrowser
-        if self.config['showfig']:
-            self.showfig(self.config['filepath'])
-            # webbrowser.open(os.path.abspath(self.config['filepath']), new=2)
-        # Return
-        return self.G
+        html = self.write_html(json_data, overwrite=overwrite)
+        # Display the chart
+        return self.display(html)
 
-    @staticmethod
-    def showfig(filepath: str, sleep: float = 0.5) -> None:
-        """Show figure."""
-        # Sleeping is required to prevent overlapping windows
-        time.sleep(sleep)
-        file_location = os.path.abspath(filepath)
-        if platform == "darwin":  # check if on OSX
-            file_location = "file:///" + file_location
-        webbrowser.open(file_location, new=2)
+    def display(self, html):
+        """Display."""
+        if self.config['notebook']:
+            import IPython
+            logger.info('Display in notebook using IPython.')
+            IPython.display.display(IPython.display.HTML(html))
+        elif self.config['filepath'] is not None:
+            # Open the webbrowser
+            self.open_browser()
+        else:
+            logger.info('Nothing to display when filepath is None and notebook is False. Return HTML.')
+            return html
+
+    def open_browser(self, sleep: float = 0.5) -> None:
+        """Open the browser to show the chart."""
+        if self.config['showfig']:
+            # Sleeping is required to prevent overlapping windows
+            time.sleep(sleep)
+            file_location = os.path.abspath(self.config['filepath'])
+            if platform == "darwin":  # check if on OSX
+                file_location = "file:///" + file_location
+            if os.path.isfile(file_location):
+                webbrowser.open(file_location, new=2)
 
     def set_edge_properties(self, edge_distance: int = None, scaler: str = 'zscore', minmax: List[float] = None, directed: bool = False, marker_start=None, marker_end='arrow', marker_color='#808080') -> dict:
         """Edge properties.
@@ -222,7 +246,16 @@ class d3graph:
 
         logger.debug('Number of edges: %.0d', len(self.edge_properties.keys()))
 
-    def set_node_properties(self, label: List[str] = None, tooltip: List[str] = None, color: Union[str, List[str]] = '#000080', size=10, edge_color='#000000', edge_size=1, cmap='Set1', scaler='zscore', minmax = [10, 50]):
+    def set_node_properties(self,
+                            label: List[str] = None,
+                            tooltip: List[str] = None,
+                            color: Union[str, List[str]] = '#000080',
+                            size=10,
+                            edge_color='#000000',
+                            edge_size=1,
+                            cmap: str = 'Set1',
+                            scaler: str = 'zscore',
+                            minmax = [10, 50]):
         """Node properties.
 
         Parameters
@@ -553,12 +586,17 @@ class d3graph:
         None.
 
         """
+        CLICK_COMMENT = ''
+        if self.config['click'] is None:
+            CLICK_COMMENT = '//'
+            self.config['click'] = {}
+        click_properties = {**{'fill': 'red', 'stroke': 'black', 'size': 1.3, 'stroke-width': 3}, **self.config['click']}
         # Hide slider.
         show_slider = ['',''] if self.config['show_slider'] else ['<!--', '-->']
         # Set width and height to screen resolution if None.
         width = 'window.screen.width' if self.config['figsize'][0] is None else self.config['figsize'][0]
         height = 'window.screen.height' if self.config['figsize'][1] is None else self.config['figsize'][1]
-        
+
         content = {'json_data'    : json_data,
                    'title'        : self.config['network_title'],
                    'width'        : width,
@@ -569,23 +607,36 @@ class d3graph:
                    'max_slider'   : self.config['slider'][1],
                    'directed'     : self.config['directed'],
                    'collision'    : self.config['collision'],
+                   'CLICK_COMMENT': CLICK_COMMENT,
+                   'CLICK_FILL'   : click_properties['fill'],
+                   'CLICK_STROKE' : click_properties['stroke'],
+                   'CLICK_SIZE'   : click_properties['size'],
+                   'CLICK_STROKEW': click_properties['stroke-width'],
                    'slider_comment_start' : show_slider[0],
                    'slider_comment_stop'  : show_slider[1],
                    }
+
         # Issue14: https://github.com/erdogant/d3graph/issues/14
         try:
             jinja_env = Environment(loader=PackageLoader(package_name=__name__, package_path='d3js'))
         except:
             jinja_env = Environment(loader=PackageLoader(package_name='d3graph', package_path='d3js'))
         index_template = jinja_env.get_template('index.html.j2')
-        index_file = Path(self.config['filepath'])
-        logger.info(f'Write to path: [{index_file.absolute()}]')
+        html = index_template.render(content)
+
+        index_file = self.config['filepath']
         # index_file.write_text(index_template.render(content))
-        if os.path.isfile(index_file) and overwrite:
+        if overwrite and index_file:
+            logger.info(f'Write to path: [{index_file.absolute()}]')
             logger.info(f'File already exists and will be overwritten: [{index_file}]')
-            os.remove(index_file)
-        with open(index_file, 'w', encoding='utf-8') as f:
-            f.write(index_template.render(content))
+            if os.path.isfile(index_file): os.remove(index_file)
+            with open(index_file, 'w', encoding='utf-8') as f:
+                f.write(html)
+
+        # Generate html content
+        # write_html_file(config, html, logger)
+        # Return html
+        return html
 
     def set_path(self, filepath='d3graph.html') -> str:
         """Set the file path.
@@ -604,6 +655,9 @@ class d3graph:
             Path to graph.
 
         """
+        if filepath is None:
+            return None
+
         dirname, filename = os.path.split(filepath)
 
         if filename in (None, ''):
@@ -615,7 +669,7 @@ class d3graph:
         os.makedirs(dirname, exist_ok=True)
         filepath = os.path.abspath(os.path.join(dirname, filename))
         logger.debug(f'filepath is set to [{filepath}]')
-        return filepath
+        return Path(filepath)
 
     def import_example(self, network='small'):
         """Import example.
@@ -876,11 +930,10 @@ def make_graph(node_properties: dict, edge_properties: dict) -> dict:
     G = nx.DiGraph()
     G = edges2G(edge_properties, G=G)
     G = nodes2G(node_properties, G=G)
-
     return G
 
 
-# %% Normalize in good d3 range
+# %% Normalize.
 def _normalize_size(getsizes, minscale: Union[int, float] = 0.5, maxscale: Union[int, float] = 4, scaler: str = 'zscore'):
     # Instead of Min-Max scaling, that shrinks any distribution in the [0, 1] interval, scaling the variables to
     # Z-scores is better. Min-Max Scaling is too sensitive to outlier observations and generates unseen problems,
@@ -889,6 +942,11 @@ def _normalize_size(getsizes, minscale: Union[int, float] = 0.5, maxscale: Union
         getsizes = (getsizes.flatten() - np.mean(getsizes)) / np.std(getsizes)
         getsizes = getsizes + (minscale - np.min(getsizes))
     elif scaler == 'minmax':
+        try:
+            from sklearn.preprocessing import MinMaxScaler
+        except:
+            raise Exception('sklearn needs to be pip installed first. Try: pip install scikit-learn')
+        # scaling
         getsizes = MinMaxScaler(feature_range=(minscale, maxscale)).fit_transform(getsizes).flatten()
     else:
         getsizes = getsizes.ravel()
