@@ -4,7 +4,6 @@ import pandas as pd
 import numpy as np
 from d3graph import d3graph, adjmat2vec
 
-
 # %%
 from d3graph import d3graph
 
@@ -15,7 +14,42 @@ adjmat, df = d3.import_example('karate')
 d3.graph(adjmat, color='cluster')
 d3.show(figsize=(None, None))
 
-d3.set_node_properties(color='cluster')
+d3.set_node_properties(color='cluster', scaler='minmax')
+d3.show(figsize=(1500, 1200))
+
+
+# %% on click
+from d3graph import d3graph
+d3 = d3graph()
+adjmat, df = d3.import_example('karate')
+d3.graph(adjmat, color='cluster')
+html = d3.show(click={'fill': 'green', 'stroke': 'black', 'size': 2, 'stroke-width': 2}, filepath=r'c:\temp\d3graph\d3graph.html')
+html = d3.show(click=None, filepath=r'c:\temp\d3graph\d3graph.html')
+html = d3.show(filepath=r'c:\temp\d3graph\d3graph.html')
+
+# %% notebook examples
+from d3graph import d3graph
+d3 = d3graph()
+adjmat, df = d3.import_example('karate')
+d3.graph(adjmat, color='cluster')
+html = d3.show(filepath=None, notebook=False)
+assert html is not None
+html = d3.show(filepath=None, notebook=True)
+assert html is None
+html = d3.show(filepath='test.html', notebook=False)
+assert html is None
+
+# %%
+from d3graph import d3graph
+
+d3 = d3graph()
+# Load example
+adjmat, df = d3.import_example('karate')
+
+d3.graph(adjmat, color='cluster')
+d3.show(figsize=(None, None))
+
+d3.set_node_properties(color='cluster', scaler='minmax')
 d3.show(figsize=(1500, 1200))
 
 
